summaryrefslogtreecommitdiff
path: root/libguile/ramap.c
diff options
context:
space:
mode:
authorGreg J. Badros <gjb@cs.washington.edu>2000-01-06 19:51:45 +0000
committerGreg J. Badros <gjb@cs.washington.edu>2000-01-06 19:51:45 +0000
commitc3ee75204c0b9c3cff2071d3ec4d5271bf5b1784 (patch)
treed6345359745bf67a841ea8710625f24ac636020b /libguile/ramap.c
parent2cc0f8cb17363f7d8c916939398b3857751a3862 (diff)
downloadguile-c3ee75204c0b9c3cff2071d3ec4d5271bf5b1784.tar.gz
* *.c, snarf.h: Replace GUILE_PROC1 with SCM_DEFINE1 throughout.
Diffstat (limited to 'libguile/ramap.c')
-rw-r--r--libguile/ramap.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/libguile/ramap.c b/libguile/ramap.c
index 0b8aac370..133d0e2db 100644
--- a/libguile/ramap.c
+++ b/libguile/ramap.c
@@ -2041,8 +2041,8 @@ scm_raequal (SCM ra0, SCM ra1)
}
#if 0
-/* GJB:FIXME:: Why not use GUILE_PROC1 for array-equal? */
-GUILE_PROC1(scm_array_equal_p, "array-equal?", scm_tc7_rpsubr,
+/* GJB:FIXME:: Why not use SCM_DEFINE1 for array-equal? */
+SCM_DEFINE1 (scm_array_equal_p, "array-equal?", scm_tc7_rpsubr,
(SCM ra0, SCM ra1),
"Returns @code{#t} iff all arguments are arrays with the same shape, the
same type, and have corresponding elements which are either